@@ -15,7 +15,21 @@ eff_dof <- function(cov.par, X, cov_func, outer.W, taper) {
 
   XtiS <- crossprod(X, iSigma)
 
-  as.numeric(nug.var * tr(solve(XtiS %*% X) %*% XtiS%*% iSigma %*% X) +
-    n + nug.var * tr(iSigma))
+  # trace of hat matrix
+  as.numeric(tr(X %*% solve(XtiS %*% X) %*% XtiS))
+
+  # as.numeric(nug.var * tr(solve(XtiS %*% X) %*% XtiS%*% iSigma %*% X) +
+  #   n + nug.var * tr(iSigma))
 
 }
+
+tr_Sigma <- function(cov.par, X, cov_func, outer.W, taper) {
+
+  n <- nrow(X)
+  nug.var <- tail(cov.par, 1)
+  p <- length(outer.W)
+
+
+  tr(Sigma_y(cov.par, p, cov_func, outer.W, taper)) - nug.var*n
+}
+
